.. PyPendentDrop documentation master file, created by
   sphinx-quickstart on Wed Oct 23 22:18:20 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

PyPendentDrop documentation
===========================

Python library (with graphical and command line interfaces) to measure surface tension from images of pendent drops.

* Package on `PyPI <https://pypi.org/project/pypendentdrop>`_
* Source code on `GitHub <https://github.com/Moryavendil/pypendentdrop>`_


PyPendentDrop is heavily inspired from the `Pendent Drop ImageJ plugin <https://github.com/adaerr/pendent-drop>`_.

.. toctree::
   :maxdepth: 1
   :caption: PyPendentDrop documentation:
   
   installation
   howtouse
   method
   API

